.. _wiimatch_step:

Weighted Image Intensity Matching
=================================

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. include:: README.md

.. toctree::
   :maxdepth: 2

   match
   lsq_optimizer
   utils
